Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtractFirsts ¶
ExtractFirsts extracts all the first elements from the given slice of pairs.
Parameters:
- pairs: The slice of pairs.
Returns:
- []A: The slice of first elements.
func ExtractSeconds ¶
ExtractSeconds extracts all the second elements from the given slice of pairs.
Parameters:
- pairs: The slice of pairs.
Returns:
- []B: The slice of second elements.
Types ¶
Click to show internal directories.
Click to hide internal directories.